"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2013 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

import logging

from sleekxmppfs.xmlstream import register_stanza_plugin
from sleekxmppfs.plugins import BasePlugin
from sleekxmppfs.plugins.google.auth import stanza


log = logging.getLogger(__name__)


class GoogleAuth(BasePlugin):

    """
    Google: Auth Extensions (JID Domain Discovery, OAuth2)

    Also see:
        <https://developers.google.com/talk/jep_extensions/jid_domain_change>
        <https://developers.google.com/talk/jep_extensions/oauth>
    """

    name = 'google_auth'
    description = 'Google: Auth Extensions (JID Domain Discovery, OAuth2)'
    dependencies = set(['feature_mechanisms'])
    stanza = stanza

    def plugin_init(self):
        self.xmpp.namespace_map['http://www.google.com/talk/protocol/auth'] = 'ga'

        register_stanza_plugin(self.xmpp['feature_mechanisms'].stanza.Auth,
                               stanza.GoogleAuth)

        self.xmpp.add_filter('out', self._auth)

    def plugin_end(self):
        self.xmpp.del_filter('out', self._auth)

    def _auth(self, stanza):
        if isinstance(stanza, self.xmpp['feature_mechanisms'].stanza.Auth):
            stanza.stream = self.xmpp
            stanza['google']['client_uses_full_bind_result'] = True
            if stanza['mechanism'] == 'X-OAUTH2':
                stanza['google']['service'] = 'oauth2'
            print(stanza)
        return stanza



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2010  Nathanael C. Fritz
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.xmlstream.matcher.id import MatcherId
from sleekxmppfs.xmlstream.matcher.idsender import MatchIDSender
from sleekxmppfs.xmlstream.matcher.many import MatchMany
from sleekxmppfs.xmlstream.matcher.stanzapath import StanzaPath
from sleekxmppfs.xmlstream.matcher.xmlmask import MatchXMLMask
from sleekxmppfs.xmlstream.matcher.xpath import MatchXPath

__all__ = ['MatcherId', 'MatchMany', 'StanzaPath',
           'MatchXMLMask', 'MatchXPath']



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.plugins.base import register_plugin

from sleekxmppfs.plugins.xep_0091 import stanza
from sleekxmppfs.plugins.xep_0091.stanza import LegacyDelay
from sleekxmppfs.plugins.xep_0091.legacy_delay import XEP_0091


register_plugin(XEP_0091)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2007-2011 Nathanael C. Fritz
# All Rights Reserved
#
# This software is licensed as described in the README.rst and LICENSE
# file, which you should have received as part of this distribution.

import sys
import codecs
try:
    from setuptools import setup, Command
except ImportError:
    from distutils.core import setup, Command
# from ez_setup import use_setuptools

from testall import TestCommand
from sleekxmppfs.version import __version__
# if 'cygwin' in sys.platform.lower():
#     min_version = '0.6c6'
# else:
#     min_version = '0.6a9'
#
# try:
#     use_setuptools(min_version=min_version)
# except TypeError:
#     # locally installed ez_setup won't have min_version
#     use_setuptools()
#
# from setuptools import setup, find_packages, Extension, Feature

VERSION          = __version__
DESCRIPTION      = 'A fork of SleekXMPP with TLS cert validation disabled, intended only to be used with the sucks project'
with codecs.open('README.rst', 'r', encoding='UTF-8') as readme:
    LONG_DESCRIPTION = ''.join(readme)

CLASSIFIERS      = [ 'Intended Audience :: Developers',
                     'License :: OSI Approved :: MIT License',
                     'Programming Language :: Python',
                     'Programming Language :: Python :: 2.6',
                     'Programming Language :: Python :: 2.7',
                     'Programming Language :: Python :: 3.1',
                     'Programming Language :: Python :: 3.2',
                     'Programming Language :: Python :: 3.3',
                     'Topic :: Software Development :: Libraries :: Python Modules',
                   ]

packages     = [ 'sleekxmppfs',
                 'sleekxmppfs/stanza',
                 'sleekxmppfs/test',
                 'sleekxmppfs/roster',
                 'sleekxmppfs/util',
                 'sleekxmppfs/util/sasl',
                 'sleekxmppfs/xmlstream',
                 'sleekxmppfs/xmlstream/matcher',
                 'sleekxmppfs/xmlstream/handler',
                 'sleekxmppfs/plugins',
                 'sleekxmppfs/plugins/xep_0004',
                 'sleekxmppfs/plugins/xep_0004/stanza',
                 'sleekxmppfs/plugins/xep_0009',
                 'sleekxmppfs/plugins/xep_0009/stanza',
                 'sleekxmppfs/plugins/xep_0012',
                 'sleekxmppfs/plugins/xep_0013',
                 'sleekxmppfs/plugins/xep_0016',
                 'sleekxmppfs/plugins/xep_0020',
                 'sleekxmppfs/plugins/xep_0027',
                 'sleekxmppfs/plugins/xep_0030',
                 'sleekxmppfs/plugins/xep_0030/stanza',
                 'sleekxmppfs/plugins/xep_0033',
                 'sleekxmppfs/plugins/xep_0047',
                 'sleekxmppfs/plugins/xep_0048',
                 'sleekxmppfs/plugins/xep_0049',
                 'sleekxmppfs/plugins/xep_0050',
                 'sleekxmppfs/plugins/xep_0054',
                 'sleekxmppfs/plugins/xep_0059',
                 'sleekxmppfs/plugins/xep_0060',
                 'sleekxmppfs/plugins/xep_0060/stanza',
                 'sleekxmppfs/plugins/xep_0065',
                 'sleekxmppfs/plugins/xep_0066',
                 'sleekxmppfs/plugins/xep_0071',
                 'sleekxmppfs/plugins/xep_0077',
                 'sleekxmppfs/plugins/xep_0078',
                 'sleekxmppfs/plugins/xep_0080',
                 'sleekxmppfs/plugins/xep_0084',
                 'sleekxmppfs/plugins/xep_0085',
                 'sleekxmppfs/plugins/xep_0086',
                 'sleekxmppfs/plugins/xep_0091',
                 'sleekxmppfs/plugins/xep_0092',
                 'sleekxmppfs/plugins/xep_0095',
                 'sleekxmppfs/plugins/xep_0096',
                 'sleekxmppfs/plugins/xep_0107',
                 'sleekxmppfs/plugins/xep_0108',
                 'sleekxmppfs/plugins/xep_0115',
                 'sleekxmppfs/plugins/xep_0118',
                 'sleekxmppfs/plugins/xep_0122',
                 'sleekxmppfs/plugins/xep_0128',
                 'sleekxmppfs/plugins/xep_0131',
                 'sleekxmppfs/plugins/xep_0152',
                 'sleekxmppfs/plugins/xep_0153',
                 'sleekxmppfs/plugins/xep_0172',
                 'sleekxmppfs/plugins/xep_0184',
                 'sleekxmppfs/plugins/xep_0186',
                 'sleekxmppfs/plugins/xep_0191',
                 'sleekxmppfs/plugins/xep_0196',
                 'sleekxmppfs/plugins/xep_0198',
                 'sleekxmppfs/plugins/xep_0199',
                 'sleekxmppfs/plugins/xep_0202',
                 'sleekxmppfs/plugins/xep_0203',
                 'sleekxmppfs/plugins/xep_0221',
                 'sleekxmppfs/plugins/xep_0224',
                 'sleekxmppfs/plugins/xep_0231',
                 'sleekxmppfs/plugins/xep_0235',
                 'sleekxmppfs/plugins/xep_0249',
                 'sleekxmppfs/plugins/xep_0257',
                 'sleekxmppfs/plugins/xep_0258',
                 'sleekxmppfs/plugins/xep_0279',
                 'sleekxmppfs/plugins/xep_0280',
                 'sleekxmppfs/plugins/xep_0297',
                 'sleekxmppfs/plugins/xep_0308',
                 'sleekxmppfs/plugins/xep_0313',
                 'sleekxmppfs/plugins/xep_0319',
                 'sleekxmppfs/plugins/xep_0323',
                 'sleekxmppfs/plugins/xep_0323/stanza',
                 'sleekxmppfs/plugins/xep_0325',
                 'sleekxmppfs/plugins/xep_0325/stanza',
                 'sleekxmppfs/plugins/xep_0332',
                 'sleekxmppfs/plugins/xep_0332/stanza',
                 'sleekxmppfs/plugins/google',
                 'sleekxmppfs/plugins/google/gmail',
                 'sleekxmppfs/plugins/google/auth',
                 'sleekxmppfs/plugins/google/settings',
                 'sleekxmppfs/plugins/google/nosave',
                 'sleekxmppfs/features',
                 'sleekxmppfs/features/feature_mechanisms',
                 'sleekxmppfs/features/feature_mechanisms/stanza',
                 'sleekxmppfs/features/feature_starttls',
                 'sleekxmppfs/features/feature_bind',
                 'sleekxmppfs/features/feature_session',
                 'sleekxmppfs/features/feature_rosterver',
                 'sleekxmppfs/features/feature_preapproval',
                 'sleekxmppfs/thirdparty',
                 ]

setup(
    name             = "sleekxmppfs",
    version          = VERSION,
    description      = DESCRIPTION,
    long_description = LONG_DESCRIPTION,
    author       = 'Greg Laabs',
    author_email = 'OverloadUT@gmail.com',
    url          = 'http://github.com/OverloadUT/SleekXMPP',
    license      = 'MIT',
    platforms    = [ 'any' ],
    packages     = packages,
    requires     = [ 'dnspython', 'pyasn1', 'pyasn1_modules' ],
    classifiers  = CLASSIFIERS,
    cmdclass     = {'test': TestCommand}
)



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2011 Nathanael C. Fritz, Dann Martens (TOMOTON).
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.plugins.base import register_plugin

from sleekxmppfs.plugins.xep_0009 import stanza
from sleekxmppfs.plugins.xep_0009.rpc import XEP_0009
from sleekxmppfs.plugins.xep_0009.stanza import RPCQuery, MethodCall, MethodResponse


register_plugin(XEP_0009)


# Retain some backwards compatibility
xep_0009 = XEP_0009



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.plugins.base import register_plugin

from sleekxmppfs.plugins.xep_0257 import stanza
from sleekxmppfs.plugins.xep_0257.stanza import Certs, AppendCert
from sleekxmppfs.plugins.xep_0257.stanza import DisableCert, RevokeCert
from sleekxmppfs.plugins.xep_0257.client_cert_management import XEP_0257


register_plugin(XEP_0257)



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2011 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs import Iq
from sleekxmppfs.xmlstream import register_stanza_plugin
from sleekxmppfs.plugins import BasePlugin
from sleekxmppfs.plugins.xep_0016 import stanza
from sleekxmppfs.plugins.xep_0016.stanza import Privacy, Item


class XEP_0016(BasePlugin):

    name = 'xep_0016'
    description = 'XEP-0016: Privacy Lists'
    dependencies = set(['xep_0030'])
    stanza = stanza

    def plugin_init(self):
        register_stanza_plugin(Iq, Privacy)

    def plugin_end(self):
        self.xmpp['xep_0030'].del_feature(feature=Privacy.namespace)

    def session_bind(self, jid):
        self.xmpp['xep_0030'].add_feature(Privacy.namespace)

    def get_privacy_lists(self, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'get'
        iq.enable('privacy')
        return iq.send(block=block, timeout=timeout, callback=callback)

    def get_list(self, name, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'get'
        iq['privacy']['list']['name'] = name
        return iq.send(block=block, timeout=timeout, callback=callback)

    def get_active(self, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'get'
        iq['privacy'].enable('active')
        return iq.send(block=block, timeout=timeout, callback=callback)

    def get_default(self, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'get'
        iq['privacy'].enable('default')
        return iq.send(block=block, timeout=timeout, callback=callback)

    def activate(self, name, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'set'
        iq['privacy']['active']['name'] = name
        return iq.send(block=block, timeout=timeout, callback=callback)

    def deactivate(self, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'set'
        iq['privacy'].enable('active')
        return iq.send(block=block, timeout=timeout, callback=callback)

    def make_default(self, name, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'set'
        iq['privacy']['default']['name'] = name
        return iq.send(block=block, timeout=timeout, callback=callback)

    def remove_default(self, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'set'
        iq['privacy'].enable('default')
        return iq.send(block=block, timeout=timeout, callback=callback)

    def edit_list(self, name, rules, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'set'
        iq['privacy']['list']['name'] = name
        priv_list = iq['privacy']['list']

        if not rules:
            rules = []

        for rule in rules:
            if isinstance(rule, Item):
                priv_list.append(rule)
                continue

            priv_list.add_item(
                rule['value'],
                rule['action'],
                rule['order'],
                itype=rule.get('type', None),
                iq=rule.get('iq', None),
                message=rule.get('message', None),
                presence_in=rule.get('presence_in',
                    rule.get('presence-in', None)),
                presence_out=rule.get('presence_out',
                    rule.get('presence-out', None)))

    def remove_list(self, name, block=True, timeout=None, callback=None):
        iq = self.xmpp.Iq()
        iq['type'] = 'set'
        iq['privacy']['list']['name'] = name
        return iq.send(block=block, timeout=timeout, callback=callback)




from sleekxmppfs.plugins.base import register_plugin
from sleekxmppfs.plugins.xep_0122.stanza import FormValidation
from sleekxmppfs.plugins.xep_0122.data_validation import XEP_0122


register_plugin(XEP_0122)


# Retain some backwards compatibility
xep_0122 = XEP_0122



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2012  Nathanael C. Fritz
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

import logging

from sleekxmppfs.stanza import StreamFeatures
from sleekxmppfs.features.feature_preapproval import stanza
from sleekxmppfs.xmlstream import register_stanza_plugin
from sleekxmppfs.plugins.base import BasePlugin


log = logging.getLogger(__name__)


class FeaturePreApproval(BasePlugin):

    name = 'feature_preapproval'
    description = 'RFC 6121: Stream Feature: Subscription Pre-Approval'
    dependences = set()
    stanza = stanza

    def plugin_init(self):
        self.xmpp.register_feature('preapproval',
                self._handle_preapproval,
                restart=False,
                order=9001)

        register_stanza_plugin(StreamFeatures, stanza.PreApproval)

    def _handle_preapproval(self, features):
        """Save notice that the server support subscription pre-approvals.

        Arguments:
            features -- The stream features stanza.
        """
        log.debug("Server supports subscription pre-approvals.")
        self.xmpp.features.add('preapproval')



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2013 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.plugins.base import register_plugin

from sleekxmppfs.plugins.xep_0152 import stanza
from sleekxmppfs.plugins.xep_0152.stanza import Reachability
from sleekxmppfs.plugins.xep_0152.reachability import XEP_0152


register_plugin(XEP_0152)



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

import hashlib
import logging
import threading

from sleekxmppfs.stanza import Presence
from sleekxmppfs.exceptions import XMPPError
from sleekxmppfs.xmlstream import register_stanza_plugin
from sleekxmppfs.plugins.base import BasePlugin
from sleekxmppfs.plugins.xep_0153 import stanza, VCardTempUpdate


log = logging.getLogger(__name__)


class XEP_0153(BasePlugin):

    name = 'xep_0153'
    description = 'XEP-0153: vCard-Based Avatars'
    dependencies = set(['xep_0054'])
    stanza = stanza

    def plugin_init(self):
        self._hashes = {}

        self._allow_advertising = threading.Event()

        register_stanza_plugin(Presence, VCardTempUpdate)

        self.xmpp.add_filter('out', self._update_presence)

        self.xmpp.add_event_handler('session_start', self._start)
        self.xmpp.add_event_handler('session_end', self._end)

        self.xmpp.add_event_handler('presence_available', self._recv_presence)
        self.xmpp.add_event_handler('presence_dnd', self._recv_presence)
        self.xmpp.add_event_handler('presence_xa', self._recv_presence)
        self.xmpp.add_event_handler('presence_chat', self._recv_presence)
        self.xmpp.add_event_handler('presence_away', self._recv_presence)

        self.api.register(self._set_hash, 'set_hash', default=True)
        self.api.register(self._get_hash, 'get_hash', default=True)
        self.api.register(self._reset_hash, 'reset_hash', default=True)

    def plugin_end(self):
        self.xmpp.del_filter('out', self._update_presence)
        self.xmpp.del_event_handler('session_start', self._start)
        self.xmpp.del_event_handler('session_end', self._end)
        self.xmpp.del_event_handler('presence_available', self._recv_presence)
        self.xmpp.del_event_handler('presence_dnd', self._recv_presence)
        self.xmpp.del_event_handler('presence_xa', self._recv_presence)
        self.xmpp.del_event_handler('presence_chat', self._recv_presence)
        self.xmpp.del_event_handler('presence_away', self._recv_presence)

    def set_avatar(self, jid=None, avatar=None, mtype=None, block=True,
                   timeout=None, callback=None):
        if jid is None:
            jid = self.xmpp.boundjid.bare

        vcard = self.xmpp['xep_0054'].get_vcard(jid, cached=True)
        vcard = vcard['vcard_temp']
        vcard['PHOTO']['TYPE'] = mtype
        vcard['PHOTO']['BINVAL'] = avatar

        self.xmpp['xep_0054'].publish_vcard(jid=jid, vcard=vcard)

        self.api['reset_hash'](jid)
        self.xmpp.roster[jid].send_last_presence()

    def _start(self, event):
        try:
            vcard = self.xmpp['xep_0054'].get_vcard(self.xmpp.boundjid.bare)
            data = vcard['vcard_temp']['PHOTO']['BINVAL']
            if not data:
                new_hash = ''
            else:
                new_hash = hashlib.sha1(data).hexdigest()
            self.api['set_hash'](self.xmpp.boundjid, args=new_hash)
            self._allow_advertising.set()
        except XMPPError:
            log.debug('Could not retrieve vCard for %s' % self.xmpp.boundjid.bare)

    def _end(self, event):
        self._allow_advertising.clear()

    def _update_presence(self, stanza):
        if not isinstance(stanza, Presence):
            return stanza

        if stanza['type'] not in ('available', 'dnd', 'chat', 'away', 'xa'):
            return stanza

        current_hash = self.api['get_hash'](stanza['from'])
        stanza['vcard_temp_update']['photo'] = current_hash
        return stanza

    def _reset_hash(self, jid, node, ifrom, args):
        own_jid = (jid.bare == self.xmpp.boundjid.bare)
        if self.xmpp.is_component:
            own_jid = (jid.domain == self.xmpp.boundjid.domain)

        self.api['set_hash'](jid, args=None)
        if own_jid:
            self.xmpp.roster[jid].send_last_presence()

        try:
            iq = self.xmpp['xep_0054'].get_vcard(jid=jid.bare, ifrom=ifrom)

            data = iq['vcard_temp']['PHOTO']['BINVAL']
            if not data:
                new_hash = ''
            else:
                new_hash = hashlib.sha1(data).hexdigest()

            self.api['set_hash'](jid, args=new_hash)
        except XMPPError:
            log.debug('Could not retrieve vCard for %s' % jid)

    def _recv_presence(self, pres):
        try:
            if pres['muc']['affiliation']:
                # Don't process vCard avatars for MUC occupants
                # since they all share the same bare JID.
                return
        except: pass    

        if not pres.match('presence/vcard_temp_update'):
            self.api['set_hash'](pres['from'], args=None)
            return

        data = pres['vcard_temp_update']['photo']
        if data is None:
            return
        elif data == '' or data != self.api['get_hash'](pres['from']):
            ifrom = pres['to'] if self.xmpp.is_component else None
            self.api['reset_hash'](pres['from'], ifrom=ifrom)
            self.xmpp.event('vcard_avatar_update', pres)

    # =================================================================

    def _get_hash(self, jid, node, ifrom, args):
        return self._hashes.get(jid.bare, None)

    def _set_hash(self, jid, node, ifrom, args):
        self._hashes[jid.bare] = args



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2011 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.plugins.base import register_plugin

from sleekxmppfs.plugins.xep_0050.stanza import Command
from sleekxmppfs.plugins.xep_0050.adhoc import XEP_0050


register_plugin(XEP_0050)


# Retain some backwards compatibility
xep_0050 = XEP_0050



"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

from sleekxmppfs.plugins.base import register_plugin

from sleekxmppfs.plugins.xep_0198.stanza import Enable, Enabled
from sleekxmppfs.plugins.xep_0198.stanza import Resume, Resumed
from sleekxmppfs.plugins.xep_0198.stanza import Failed
from sleekxmppfs.plugins.xep_0198.stanza import StreamManagement
from sleekxmppfs.plugins.xep_0198.stanza import Ack, RequestAck

from sleekxmppfs.plugins.xep_0198.stream_management import XEP_0198


register_plugin(XEP_0198)
